==> py-hostlist-0.0.1.dev0.tar.gz: py-hostlist-0.0.1.dev0/README.md <==
# <img src="https://openclipart.org/download/284280/publicdomainq-0008487gctues.svg" width="64" valign="middle" alt="Py"/> py-hostlist: a tool for manipulating lists of hosts

[![Build Status](https://travis-ci.org/LLNL/py-hostlist.svg?branch=master)](https://travis-ci.org/LLNL/py-hostlist)
[![Documentation Status](https://readthedocs.org/projects/py-hostlist/badge/?version=latest)](https://py-hostlist.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/LLNL/py-hostlist/branch/master/graph/badge.svg)](https://codecov.io/gh/LLNL/py-hostlist)
[![Issues](https://img.shields.io/github/issues/LLNL/py-hostlist.svg)](https://github.com/LLNL/py-hostlist/issues)
[![Stars](https://img.shields.io/github/stars/LLNL/py-hostlist.svg)](https://github.com/LLNL/py-hostlist/stargazers)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/LLNL/py-hostlist/master/LICENSE)

## Description

py-hostlist processes slurm-style hostlist strings and can return those strings in manipulated fashion. 

See the [Feature Overview](https://py-hostlist.readthedocs.io/en/latest/features.html) for examples and highlights.

## Documentation

Full documentation on py-hostlist can be found at [ReadtheDocs](https://py-hostlist.readthedocs.io/en/latest/index.html#).

## Contributions

Contributing to py-hostlist is relatively easy. Just send us a
[pull request](https://help.github.com/articles/using-pull-requests/). When you send your request, make ``develop`` the destination branch on the [py-hostlist repository](https://github.com/LLNL/py-hostlist).

Your PR must pass py-hostlist's unit tests. We enforce these guidelines with [Travis CI](https://travis-ci.org/LLNL/py-hostlist). To run these tests locally, and for helpful tips on git, see our [Contribution Guide](https://py-hostlist.readthedocs.io/en/latest/contribution_guide.html).


## Authors

#### Christopher Moussa, moussa1@llnl.gov

A huge thank you to **Elsa Gonsiorowski** for serving as a mentor on this project. 

## Release

Copyright (c) 2018, Lawrence Livermore National Security, LLC.
Produced at the Lawrence Livermore National Laboratory.

For release details and restrictions, please read the [LICENSE](https://github.com/LLNL/py-hostlist/blob/master/LICENSE) and [NOTICE](https://github.com/LLNL/py-hostlist/blob/master/NOTICE) files.

`LLNL-CODE-411039`

==> py-hostlist-0.0.2.dev0.tar.gz: py-hostlist-0.0.2.dev0/README.md <==
# <img src="https://openclipart.org/download/284280/publicdomainq-0008487gctues.svg" width="64" valign="middle" alt="Py"/> py-hostlist: a tool for manipulating lists of hosts

[![Build Status](https://travis-ci.org/LLNL/py-hostlist.svg?branch=master)](https://travis-ci.org/LLNL/py-hostlist)
[![Documentation Status](https://readthedocs.org/projects/py-hostlist/badge/?version=latest)](https://py-hostlist.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/LLNL/py-hostlist/branch/master/graph/badge.svg)](https://codecov.io/gh/LLNL/py-hostlist)
[![Issues](https://img.shields.io/github/issues/LLNL/py-hostlist.svg)](https://github.com/LLNL/py-hostlist/issues)
[![Stars](https://img.shields.io/github/stars/LLNL/py-hostlist.svg)](https://github.com/LLNL/py-hostlist/stargazers)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/LLNL/py-hostlist/master/LICENSE)

## Description

py-hostlist processes slurm-style hostlist strings and can return those strings in manipulated fashion.

See the [Feature Overview](https://py-hostlist.readthedocs.io/en/latest/features.html) for examples and highlights.

## Documentation

Full documentation on py-hostlist can be found at [ReadtheDocs](https://py-hostlist.readthedocs.io/en/latest/index.html#).

## Contributions

Contributing to py-hostlist is relatively easy. Just send us a
[pull request](https://help.github.com/articles/using-pull-requests/). When you send your request, make ``develop`` the destination branch on the [py-hostlist repository](https://github.com/LLNL/py-hostlist).

Your PR must pass py-hostlist's unit tests. We enforce these guidelines with [Travis CI](https://travis-ci.org/LLNL/py-hostlist). To run these tests locally, and for helpful tips on git, see our [Contribution Guide](https://py-hostlist.readthedocs.io/en/latest/source/contribution_guide.html).


## Authors

#### Christopher Moussa, moussa1@llnl.gov

A huge thank you to **Elsa Gonsiorowski** for serving as a mentor on this project.

## Release

Copyright (c) 2018, Lawrence Livermore National Security, LLC.
Produced at the Lawrence Livermore National Laboratory.

For release details and restrictions, please read the [LICENSE](https://github.com/LLNL/py-hostlist/blob/master/LICENSE) and [NOTICE](https://github.com/LLNL/py-hostlist/blob/master/NOTICE) files.

`LLNL-CODE-411039`
